<html>
    <head>
        <meta http-equiv="refresh" content="3;URL=/d/class"> 
        <style>
            body {
                font-style: Arial;
            }
        </style>
    </head>
    <body>
        <img src="https://transo.in/images/loading.gif" style="margin-top: 18%; margin-left: 40%;"/>
        <h1 style="text-align: center;">Loading module: {{module}}</h1>
    </body>
</html>